==> aria2-1.7.2.tar.xz: aria2-1.7.2/src/BtRequestMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_REQUEST_MESSAGE_H_
#define _D_BT_REQUEST_MESSAGE_H_

#include "RangeBtMessage.h"

namespace aria2 {

class BtRequestMessage;

typedef SharedHandle<BtRequestMessage> BtRequestMessageHandle;

class BtRequestMessage : public RangeBtMessage {
private:
  size_t _blockIndex;

public:
  BtRequestMessage(size_t index = 0,
		   uint32_t begin = 0,
		   uint32_t length = 0,
		   size_t blockIndex = 0)
    :RangeBtMessage(ID, NAME, index, begin, length),
     _blockIndex(blockIndex) {}

  static const uint8_t ID = 6;

  static const std::string NAME;

  size_t getBlockIndex() const { return _blockIndex; }
  void setBlockIndex(size_t blockIndex) { _blockIndex = blockIndex; }

  static SharedHandle<BtRequestMessage> create
  (const unsigned char* data, size_t dataLength);

  virtual void doReceivedAction();

  virtual void onQueued();

  virtual void onAbortOutstandingRequestEvent
  (const BtAbortOutstandingRequestEvent& event);
};

} // namespace aria2

#endif // _D_BT_REQUEST_MESSAGE_H_

==> aria2-1.10.3.tar.xz: aria2-1.10.3/src/BtRequestMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_REQUEST_MESSAGE_H_
#define _D_BT_REQUEST_MESSAGE_H_

#include "RangeBtMessage.h"

namespace aria2 {

class BtRequestMessage;

typedef SharedHandle<BtRequestMessage> BtRequestMessageHandle;

class BtRequestMessage : public RangeBtMessage {
private:
  size_t blockIndex_;
public:
  BtRequestMessage(size_t index = 0,
                   uint32_t begin = 0,
                   uint32_t length = 0,
                   size_t blockIndex = 0);

  static const uint8_t ID = 6;

  static const std::string NAME;

  size_t getBlockIndex() const { return blockIndex_; }
  void setBlockIndex(size_t blockIndex) { blockIndex_ = blockIndex; }

  static SharedHandle<BtRequestMessage> create
  (const unsigned char* data, size_t dataLength);

  virtual void doReceivedAction();

  virtual void onQueued();

  virtual void onAbortOutstandingRequestEvent
  (const BtAbortOutstandingRequestEvent& event);
};

} // namespace aria2

#endif // _D_BT_REQUEST_MESSAGE_H_
